BinICC: A function for calculating the intracluster correlation coefficient (ICC) for binary outcomes given the cluster level random effects variance
Description
This function calculates the ICC (intracluster correlation coeffcient which measures the correlation between individuals in the same cluster) under different link funcitions in a cross-sectional stepped wedge CRT with binary outcomes. This model considers only the fixed time effects and does not include cluster by time interaction random effect.